@@ -6,12 +6,16 @@
 #
 #Tested with SoundscapeMeter 1.0.14.05.2012, courtesy of A. Farina
 #
-acoustic_complexity <- function(soundfile, max_freq = NA, j = 5, fft_w = 512){
+acoustic_complexity <- function(soundfile, min_freq = NA, max_freq = NA, j = 5, fft_w = 512){
 	
-	if (is.na(max_freq)){
-		max_freq <- soundfile@samp.rate / 2
-	}
-
+  if (is.na(max_freq)){
+    max_freq <- soundfile@samp.rate / 2
+  }
+  
+  if (is.na(min_freq)){
+    min_freq <- 0
+  }
+  
 	#function that gets the difference of values
 	get_d <- function(spectrum, freq_row, min_col, max_col){
 		D = 0
@@ -46,24 +50,54 @@ acoustic_complexity <- function(soundfile, max_freq = NA, j = 5, fft_w = 512){
 				
 		#matrix of values
 		cat("\n Calculating index. Please wait... \n\n")
-		specA_left <- spectro(left, f = samplingrate, wl = wlen, plot = FALSE, norm = TRUE, dB = NULL, scale = FALSE, wn = "hamming")$amp
-		specA_right <- spectro(right, f = samplingrate, wl = wlen, plot = FALSE, norm = TRUE, dB = NULL, scale = FALSE, wn = "hamming")$amp
+		spec_left <- spectro(left, f = samplingrate, wl = wlen, plot = FALSE, norm = TRUE, dB = NULL, scale = FALSE, wn = "hamming")
+		
+		specA_left <- spec_left$amp
+		
+		min_freq1k = min_freq/1000 
+		max_freq1k = max_freq/1000 
+		
+		which_min_freq <- which(abs(spec_left$freq - min_freq1k)==min(abs(spec_left$freq - min_freq1k)))
+		which_max_freq <- which(abs(spec_left$freq - max_freq1k)==min(abs(spec_left$freq - max_freq1k))) 
+		  
+		if (which_min_freq <1){
+		  which_min_freq = 1
+		}
+		
+		if (which_max_freq > dim(specA_left)[1]){
+		  which_max_freq = dim(specA_left)[1]-1
+		}
+		
+# 		cat(which_min_freq)
+# 		cat(",")
+# 		cat(which_max_freq)
+# 		cat(",")
+# 		cat(dim(specA_left))
+		specA_left <- spec_left$amp[which_min_freq:which_max_freq,]
+		rm(spec_left)
+		
+		spec_right <- spectro(right, f = samplingrate, wl = wlen, plot = FALSE, norm = TRUE, dB = NULL, scale = FALSE, wn = "hamming")
+		
+		specA_right <- spec_right$amp[which_min_freq:which_max_freq,]
+		
+		rm(spec_right)
 		
 		rm(left,right)
 		
+# 		specA_rows <- dim(specA_left)[1]
+# 		specA_cols <- dim(specA_left)[2]
+# 		
+# 		freq_per_row <- specA_rows/nyquist_freq
+# 				
+# 		max_row <- round(max_freq * freq_per_row)
+# 		
+# 		specA_left <- specA_left[1:max_row,]
+# 		specA_right <- specA_right[1:max_row,]
 		specA_rows <- dim(specA_left)[1]
 		specA_cols <- dim(specA_left)[2]
 		
-		freq_per_row <- specA_rows/nyquist_freq
-				
-		max_row <- round(max_freq * freq_per_row)
-		
-		specA_left <- specA_left[1:max_row,]
-		specA_right <- specA_right[1:max_row,]
-		specA_rows <- dim(specA_left)[1]
-		
 		fl <- rep(NA, specA_rows)
-		delta_fl <- max_freq / specA_rows
+		delta_fl <- ( max_freq - min_freq ) / specA_rows
 		delta_tk <- (length(soundfile@left)/soundfile@samp.rate) / specA_cols
 				
 		#m <- floor(duration / j)
@@ -121,13 +155,21 @@ acoustic_complexity <- function(soundfile, max_freq = NA, j = 5, fft_w = 512){
 		
 		ACI_tot_right <- sum(ACI_fl_right_vector)
 		
-		cat("  Acoustic Complexity Index (total):\n")
-		cat("   Left channel: ")
+		ACI_tot_left_by_min <- round((ACI_tot_left/duration) * 60, 2)
+		ACI_tot_right_by_min <- round((ACI_tot_right/duration) * 60, 2)
+		
+		cat(paste("  Acoustic Complexity Index (total):\n", "   Left channel: ", sep=""))
 		cat(ACI_tot_left)
-		cat("\n")
-		cat("   Right channel: ")
+		cat(paste("\n", "   Right channel: ", sep=""))
 		cat(ACI_tot_right)
 		cat("\n\n")
+		if (duration > 60){
+  		cat(paste("  Acoustic Complexity Index (by minute):\n", "   Left channel: ", sep=""))
+  		cat(ACI_tot_left_by_min)
+  		cat(paste("\n", "   Right channel: ", sep=""))
+  		cat(ACI_tot_right_by_min)
+  		cat("\n\n")
+  		}
 		
 	} else 
 	{
@@ -137,22 +179,34 @@ acoustic_complexity <- function(soundfile, max_freq = NA, j = 5, fft_w = 512){
 				
 		#matrix of values
 		cat("\n Calculating index. Please wait... \n\n")
-		specA_left <- spectro(left, f = samplingrate, wl = wlen, plot = FALSE, norm = TRUE, dB = NULL, scale = FALSE, wn = "hamming")$amp
+		spec_left <- spectro(left, f = samplingrate, wl = wlen, plot = FALSE, norm = TRUE, dB = NULL, scale = FALSE, wn = "hamming")
+		
+		specA_left <- spec_left$amp
+		
+		min_freq1k = min_freq/1000 
+		max_freq1k = max_freq/1000 
+		
+		which_min_freq <- which(abs(spec_left$freq - min_freq1k)==min(abs(spec_left$freq - min_freq1k)))
+		which_max_freq <- which(abs(spec_left$freq - max_freq1k)==min(abs(spec_left$freq - max_freq1k))) 
+		
+		specA_left <- specA_left[which_min_freq:which_max_freq,]
+		rm(spec_left)
+		
 		rm(left)
 		
 		#LEFT CHANNEL
 		specA_rows <- dim(specA_left)[1]
 		specA_cols <- dim(specA_left)[2]
-		
-		freq_per_row <- specA_rows/nyquist_freq
-				
-		max_row <- round(max_freq * freq_per_row)
-		
-		specA_left <- specA_left[1:max_row,]
-		specA_rows <- dim(specA_left)[1]
+# 		
+# 		freq_per_row <- specA_rows/nyquist_freq
+# 				
+# 		max_row <- round(max_freq * freq_per_row)
+# 		
+# 		specA_left <- specA_left[1:max_row,]
+# 		specA_rows <- dim(specA_left)[1]
 		
 		fl <- rep(NA, specA_rows)
-		delta_fl <- max_freq / specA_rows
+		delta_fl <- ( max_freq - min_freq ) / specA_rows
 		delta_tk <- (length(soundfile@left)/soundfile@samp.rate) / specA_cols
 		
 		no_j <- floor(duration / j)
@@ -189,15 +243,23 @@ acoustic_complexity <- function(soundfile, max_freq = NA, j = 5, fft_w = 512){
 		} 
 		
 		ACI_tot_left <- sum(ACI_fl_left_vector)
+		ACI_tot_left_by_min <- round((ACI_tot_left/duration) * 60, 2)
 		
 		ACI_tot_right <- NA
+		ACI_tot_right_by_min <- NA
 		
 		cat("  Acoustic Complexity Index (total): ")
 		cat(ACI_tot_left)
 		cat("\n\n")
+		if (duration > 60){
+  		cat("  Acoustic Complexity Index (by minute): ")
+  		cat(ACI_tot_left_by_min)
+  		cat("\n\n")
+		  }
 	}
 	
 	invisible(list(AciTotAll_left = ACI_tot_left, AciTotAll_right = ACI_tot_right, 
+	               AciTotAll_left_bymin = ACI_tot_left_by_min, AciTotAll_right_bymin = ACI_tot_right_by_min,
 				   #AciIfTotAll_left=ACIif_tot_left, AciIfTotAll_right=ACIif_tot_right, 
 				   aci_fl_left_vals = ACI_fl_left_vector, aci_fl_right_vals = ACI_fl_right_vector,
 				   #aci_if_left_vals=ACI_if_left_vector, aci_if_right_vals=ACI_if_right_vector,
